FileHandler class
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
readExternalWallet(
Uint8List? fileBytes, {bool isIngoreVerification = false}) → List< AddressObject> ? - Reads an external wallet from a byte array and returns a list of AddressObject.
-
writeWalletFile(
List< AddressObject> addressList) → List<int> ? - Writes a list of AddressObject to a byte array.